@@ -144,6 +144,8 @@ class DiskBuilder:
         self.target_removable = xml_state.build_type.get_target_removable()
         self.root_filesystem_is_multipath = \
             xml_state.get_oemconfig_oem_multipath_scan()
+        self.oem_systemsize = xml_state.get_oemconfig_oem_systemsize()
+        self.oem_resize = xml_state.get_oemconfig_oem_resize()
         self.disk_resize_requested = \
             xml_state.get_oemconfig_oem_resize()
         self.swap_mbytes = xml_state.get_oemconfig_swap_mbytes()
@@ -294,7 +296,9 @@ class DiskBuilder:
                     'crypto_disk':
                         True if self.luks is not None else False,
                     'boot_is_crypto':
-                        self.boot_is_crypto
+                        self.boot_is_crypto,
+                    'config_options':
+                        self.xml_state.get_bootloader_config_options()
                 }
             )
 
@@ -937,7 +941,13 @@ class DiskBuilder:
             rootfs_mbsize = disksize_mbytes - disksize_used_mbytes - \
                 self.spare_part_mbsize - Defaults.get_min_partition_mbytes()
         else:
-            rootfs_mbsize = 'all_free'
+            if self.oem_systemsize and not self.oem_resize:
+                rootfs_mbsize = self.oem_systemsize
+            else:
+                rootfs_mbsize = 'all_free'
+            log.info(
+                f'--> using {rootfs_mbsize}MB for the root(rw) partition if present'
+            )
 
         if self.root_filesystem_is_overlay and \
            self.root_filesystem_has_write_partition is False:
@@ -953,10 +963,13 @@ class DiskBuilder:
                 # case
                 root_clone_count = 0
             if root_clone_count:
-                clone_rootfs_mbsize = int(
-                    (disksize_mbytes - disksize_used_mbytes) / (root_clone_count + 1)
-                ) + Defaults.get_min_partition_mbytes()
-                rootfs_mbsize = f'clone:all_free:{clone_rootfs_mbsize}'
+                if rootfs_mbsize == 'all_free':
+                    clone_rootfs_mbsize = int(
+                        (disksize_mbytes - disksize_used_mbytes) / (root_clone_count + 1)
+                    ) + Defaults.get_min_partition_mbytes()
+                    rootfs_mbsize = f'clone:all_free:{clone_rootfs_mbsize}'
+                else:
+                    rootfs_mbsize = f'clone:{rootfs_mbsize}:{rootfs_mbsize}'
             if self.volume_manager_name and self.volume_manager_name == 'lvm':
                 log.info(
                     '--> creating {0} partition [with {1} clone(s)]'.format(
@@ -1222,6 +1235,7 @@ class DiskBuilder:
             boot_options = []
             if self.mdraid:
                 boot_options.append('rd.auto')
+            ro_device = device_map.get('readonly')
             root_device = device_map['root']
             boot_device = root_device
             if 'boot' in device_map:
@@ -1237,7 +1251,8 @@ class DiskBuilder:
                 boot_uuid_unmapped
             )
             self.bootloader_config.write_meta_data(
-                root_device=device_map['root'].get_device(),
+                root_device=ro_device.get_device() if ro_device else root_device.get_device(),
+                write_device=root_device.get_device(),
                 boot_options=' '.join(boot_options)
             )
 
@@ -1248,6 +1263,7 @@ class DiskBuilder:
             kexec_boot_options = ' '.join(
                 [
                     self.bootloader_config.get_boot_cmdline(
+                        ro_device.get_device() if ro_device else root_device.get_device(),
                         device_map['root'].get_device()
                     )
                 ] + boot_options
@@ -1469,17 +1485,22 @@ class DiskBuilder:
     ) -> None:
         root_device = device_map['root']
         boot_device = root_device
+        readonly_device = None
         if 'boot' in device_map:
             boot_device = device_map['boot']
 
         if 'readonly' in device_map:
-            root_device = device_map['readonly']
+            readonly_device = device_map['readonly']
 
         custom_install_arguments = {
             'boot_device': boot_device.get_device(),
-            'root_device': root_device.get_device(),
+            'root_device':
+                readonly_device.get_device() if readonly_device else root_device.get_device(),
+            'write_device': root_device.get_device(),
             'firmware': self.firmware,
-            'target_removable': self.target_removable
+            'target_removable': self.target_removable,
+            'install_options': self.xml_state.get_bootloader_install_options(),
+            'shim_options': self.xml_state.get_bootloader_shim_options()
         }
 
         if 'efi' in device_map:
