@@ -24,7 +24,7 @@ class TestVolumeManagerBtrfs:
         self._caplog = caplog
 
     @patch('os.path.exists')
-    def setup(self, mock_VolumeManagerBtrfs, mock_path):
+    def setup(self, mock_path):
         self.volumes = [
             volume_type(
                 name='LVRoot', size='freespace:100', realpath='/',
@@ -61,6 +61,10 @@ class TestVolumeManagerBtrfs:
             self.device_map, 'root_dir', self.volumes
         )
 
+    @patch('os.path.exists')
+    def setup_method(self, cls, mock_path):
+        self.setup()
+
     def test_post_init(self):
         self.volume_manager.post_init({'some-arg': 'some-val'})
         assert self.volume_manager.custom_args['some-arg'] == 'some-val'
@@ -123,7 +127,7 @@ class TestVolumeManagerBtrfs:
 
         assert mock_mount.call_args_list == [
             call(device='/dev/storage', mountpoint='tmpdir'),
-            call(device='/dev/storage', mountpoint='tmpdir/.snapshots')
+            call(device='/dev/storage', mountpoint='tmpdir/@/.snapshots/1/snapshot/.snapshots')
         ]
         toplevel_mount.mount.assert_called_once_with([])
         assert mock_command.call_args_list == [
@@ -131,10 +135,7 @@ class TestVolumeManagerBtrfs:
             call(['btrfs', 'subvolume', 'create', 'tmpdir/@']),
             call(['btrfs', 'subvolume', 'create', 'tmpdir/@/.snapshots']),
             call(['mkdir', '-p', 'tmpdir/@/.snapshots/1']),
-            call([
-                'btrfs', 'subvolume', 'snapshot', 'tmpdir/@',
-                'tmpdir/@/.snapshots/1/snapshot'
-            ]),
+            call(['btrfs', 'subvolume', 'create', 'tmpdir/@/.snapshots/1/snapshot']),
             call(['btrfs', 'subvolume', 'list', 'tmpdir']),
             call(['btrfs', 'subvolume', 'set-default', '258', 'tmpdir'])
         ]
